aboutsummaryrefslogtreecommitdiff
path: root/tests/test-pearl-views.el
diff options
context:
space:
mode:
Diffstat (limited to 'tests/test-pearl-views.el')
-rw-r--r--tests/test-pearl-views.el4
1 files changed, 2 insertions, 2 deletions
diff --git a/tests/test-pearl-views.el b/tests/test-pearl-views.el
index 2f2adfd..a750ae0 100644
--- a/tests/test-pearl-views.el
+++ b/tests/test-pearl-views.el
@@ -20,7 +20,7 @@
;;; Commentary:
;; Tests for reading and running Linear Custom Views: the cached views list,
;; the server-side `--query-view-async' run, `pearl-run-view', the view
;; branch of refresh, and opening the active view in the browser. HTTP is
;; stubbed.
@@ -75,7 +75,7 @@
(funcall cb (pearl--make-query-result 'ok :issues nil))))
((symbol-function 'pearl--render-query-result)
(lambda (_result source) (setq rendered-source source))))
- (pearl-run-view "My View")
+ (pearl-run-linear-view "My View")
(should (string= "v1" ran-id))
(should (eq 'view (plist-get rendered-source :type)))
(should (string= "v1" (plist-get rendered-source :id)))
@@ -20,7 +20,7 @@
;;; Commentary:
;; Tests for reading and running Linear Custom Views: the cached views list,
-;; the server-side `--query-view-async' run, `pearl-run-view', the view
+;; the server-side `--query-view-async' run, `pearl-run-linear-view', the view
;; branch of refresh, and opening the active view in the browser. HTTP is
;; stubbed.